16.53. cdist-type__golang_from_vendor(7) — cdist 6.5.4 documentation

# 16.53. cdist-type__golang_from_vendor(7)

## 16.53.1. NAME

cdist-type__golang_from_vendor - Install any version of golang from golang.org

## 16.53.2. DESCRIPTION

This cdist type allows you to install golang from archives provided by https://golang.org/dl/.

See https://golang.org/dl/ for the list of supported versions, operating systems and architectures.

This is a singleton type.

## 16.53.3. REQUIRED PARAMETERS

None.

## 16.53.4. OPTIONAL PARAMETERS

version
  The golang version to install, defaults to 1.8.1

## 16.53.5. EXAMPLES

    __golang_from_vendor --version 1.8.1

## 16.53.6. AUTHORS

Kamila Součková <kamila@ksp.sk>

## 16.53.7. COPYING

Copyright (C) 2017 Kamila Součková. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.